@@ -1,7 +1,7 @@
 library(sweep)
 library(forecast)
 library(tidyquant)
-library(timekit)
+library(timetk)
 context("Testing STL tidiers")
 
 
@@ -29,7 +29,7 @@ test_that("sw_*.stl test returns tibble with correct rows and columns.", {
     expect_equal(ncol(test), 6)
 
 
-    # timekit index ----
+    # timetk index ----
 
     # data_ts <- USAccDeaths %>%
     #     tk_tbl() %>%
@@ -38,11 +38,11 @@ test_that("sw_*.stl test returns tibble with correct rows and columns.", {
     #
     # fit <- stl(data_ts, s.window = "periodic")
     #
-    # # timekit_idx sw_tidy_decomp -----
+    # # timetk_idx sw_tidy_decomp -----
     # test <- fit %>% sw_tidy_decomp()
     # expect_equal(class(test$index), "yearmon")
 
     # timekix_idx not supported with stats::stl()
-    # test <- fit %>% sw_tidy_decomp(timekit_idx = T)
+    # test <- fit %>% sw_tidy_decomp(timetk_idx = T)
     # expect_equal(class(test$index), "Date")
 })
